@@ -59,7 +59,7 @@ echo $swapsizembytes swapsizembytes
 lasttotalsmb=$(awk '{print $1}' /tmp/flopswaplast)
 echo $lasttotalsmb lasttotalsmb
 #Banner if int32 overrun
- if [ $lasttotalsmb -lt 0 ]; 
+ if [ $lasttotalsmb -lt 0 ] || [ -e $inttempfile ]; 
   then
  banner "$failed"
   sleep 1
@@ -67,8 +67,10 @@ dialog "
 
 Busybox can no longer calculate your total swap.
 Please reboot to restart calculation or use cron/alarmed to trigger FlopSwap.
+See the Wiki page found in the Help section for more details
 
 "
+touch "$inttempfile"
 exit 0
   else
 #Subtract last from current value to get latest used value
